@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use base 'Import::Export';
 
@@ -25,7 +25,7 @@ Term::ANSI::Sprintf - sprintf with ANSI colors
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
@@ -38,6 +38,10 @@ Version 0.01
 
 =head2 sprintf
 
+	%bold
+	%italic
+	%underline
+
         %black
         %red
         %green
